"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deviceCheckAndUpdateComponent = void 0;
const app_1 = require("../../core/app");
const infrastructure_1 = require("../../infrastructure");
const alwayscli_1 = require("@alwaysai/alwayscli");
const util_1 = require("../../util");
const device_1 = require("../../core/device");
const paths_1 = require("../../paths");
const constants_1 = require("../../constants");
async function deviceCheckAndUpdateComponent(props) {
    const { targetHostname, device, isNewDevice } = props;
    const spawner = (0, util_1.SshSpawner)({
        targetHostname,
        targetPath: paths_1.REMOTE_AAI_CFG_DIR_LINUX
    });
    const CLEAR_OLD_CONF_MESSAGE = "To remove old configurations from the device run 'aai device clean', and then run 'aai app configure' again.";
    if (isNewDevice) {
        await (0, util_1.runWithSpinner)(async () => {
            try {
                await (0, device_1.writeDeviceCfgFile)({ spawner, deviceUuid: device.uuid });
            }
            catch (e) {
                if (e.code === device_1.DeviceCfgErrors.TARGET_DEVICE_CONFIGURED) {
                    throw new alwayscli_1.CliTerseError(`The target device is already configured as an alwaysAI device! ${CLEAR_OLD_CONF_MESSAGE}`);
                }
                else {
                    util_1.logger.error(e.message);
                    throw new alwayscli_1.CliTerseError(`There was an error with configuring the device. ${constants_1.PLEASE_REPORT_THIS_ERROR_MESSAGE}`);
                }
            }
        }, [], 'Configure device');
    }
    else {
        await (0, util_1.runWithSpinner)(async () => {
            const hardwareId = await (0, app_1.getTargetHardwareUuid)(spawner);
            if (hardwareId !== device.hardware_ids) {
                throw new alwayscli_1.CliTerseError(`The target device does not match the selected device! ${CLEAR_OLD_CONF_MESSAGE}`);
            }
            try {
                await (0, device_1.writeOrValidateDeviceCfgFile)({
                    spawner,
                    deviceUuid: device.uuid
                });
            }
            catch (e) {
                if (e.code === device_1.DeviceCfgErrors.TARGET_DEVICE_MISMATCH) {
                    throw new alwayscli_1.CliTerseError(`The target device does not match the selected device! ${CLEAR_OLD_CONF_MESSAGE}`);
                }
                else {
                    util_1.logger.error(e.message);
                    throw new alwayscli_1.CliTerseError(`There was an error with updating the device configuration. ${constants_1.PLEASE_REPORT_THIS_ERROR_MESSAGE}`);
                }
            }
        }, [], 'Check device configuration');
    }
    if (device.mode === 'development') {
        // Production tokens don't expire, and therefore don't need to be refreshed.
        // Additionally, we don't want to overwrite existing tokens on a provisioned
        // production device.
        await (0, util_1.runWithSpinner)(async () => {
            const { accessToken, refreshToken, idToken } = await (0, infrastructure_1.refreshDevice)(device.uuid);
            const tokens = {
                deviceId: device.uuid,
                accessToken,
                refreshToken,
                idToken
            };
            await (0, device_1.writeTokens)({ spawner, tokens });
        }, [], 'Write tokens to device');
    }
}
exports.deviceCheckAndUpdateComponent = deviceCheckAndUpdateComponent;
//# sourceMappingURL=device-check-and-update-component.js.map