"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateShadow = exports.getShadow = exports.HttpStatusCode = void 0;
const authentication_client_1 = require("../infrastructure/authentication-client");
const uuid_1 = require("uuid");
const urls_1 = require("../infrastructure/urls");
const node_fetch_1 = require("node-fetch");
const _1 = require("./");
var HttpStatusCode;
(function (HttpStatusCode) {
    HttpStatusCode[HttpStatusCode["OK"] = 200] = "OK";
    HttpStatusCode[HttpStatusCode["FORBIDDEN"] = 403] = "FORBIDDEN";
})(HttpStatusCode = exports.HttpStatusCode || (exports.HttpStatusCode = {}));
const getShadow = async (thingId) => {
    const idTokenAuthorizationHeader = await (0, authentication_client_1.CliAuthenticationClient)().getIdAuthorizationHeader();
    const requestURL = (0, urls_1.serviceEndpointBuilder)('device-shadow', 'GetThingShadow');
    const body = {
        deviceUuid: thingId,
        shadowName: 'secure-tunnel',
        txId: (0, uuid_1.v4)()
    };
    _1.logger.debug('getShadow body: ', body);
    const response = await (0, node_fetch_1.default)(requestURL, {
        method: 'post',
        body: JSON.stringify(body),
        headers: Object.assign(Object.assign({}, idTokenAuthorizationHeader), { 'Content-Type': 'application/json' })
    });
    if (!response) {
        const errorMsg = 'Error: Receiving response from server';
        _1.logger.error(errorMsg);
        throw new Error(errorMsg);
    }
    // if (response.status !== HttpStatusCode.OK) {
    //   const errorMsg = `Error, response.status = ${response.status}`;
    //   logger.error(errorMsg);
    //   throw new Error(errorMsg);
    // }
    const readerStream = await response.buffer();
    const parsedJson = JSON.parse(readerStream.toString());
    return parsedJson;
};
exports.getShadow = getShadow;
const updateShadow = async (thingId, payload) => {
    const idTokenAuthorizationHeader = await (0, authentication_client_1.CliAuthenticationClient)().getIdAuthorizationHeader();
    const requestURL = (0, urls_1.serviceEndpointBuilder)('device-shadow', 'UpdateThingShadow');
    const body = {
        deviceUuid: thingId,
        shadowName: 'secure-tunnel',
        txId: (0, uuid_1.v4)(),
        payload
    };
    _1.logger.debug('updateShadow body: ', body);
    const response = await (0, node_fetch_1.default)(requestURL, {
        method: 'post',
        body: JSON.stringify(body),
        headers: Object.assign(Object.assign({}, idTokenAuthorizationHeader), { 'Content-Type': 'application/json' })
    });
    if (!response) {
        const errorMsg = 'Error: Receiving response from server';
        _1.logger.error(errorMsg);
        throw new Error(errorMsg);
    }
    if (response.status !== HttpStatusCode.OK) {
        const errorMsg = `Error, response.status = ${response.status}`;
        _1.logger.error(errorMsg);
        throw new Error(errorMsg);
    }
    const readerStream = await response.buffer();
    const parsedJson = JSON.parse(readerStream.toString());
    return parsedJson;
};
exports.updateShadow = updateShadow;
//# sourceMappingURL=shadows.js.map